==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/enumvalues_e.js <==
var searchData=
[
  ['r16',['R16',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1ae6596410cdfb3e164d3114d7275c01a4',1,'fsdk::Format']]],
  ['r8',['R8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1afd28eabff68ce04d89a4a445c8774f11',1,'fsdk::Format']]],
  ['r8g8b8',['R8G8B8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a64d817782ee8b40de7073acc65267e76',1,'fsdk::Format']]],
  ['r8g8b8x8',['R8G8B8X8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a1531807037bb455d89b70ff0d6ff05fe',1,'fsdk::Format']]],
  ['real',['Real',['../group___estimator_group.html#gga94d3646e61ffe5c0c99ea0318e359bd7a7f80fcc452c2f1ed2bb51b39d0864df1',1,'fsdk::experimental::DeepFakeEstimation::Real()'],['../structfsdk_1_1_n_i_r_liveness_estimation.html#ab465ad1dcb3273ced350445ad51aa02aa7f80fcc452c2f1ed2bb51b39d0864df1',1,'fsdk::NIRLivenessEstimation::Real()']]],
  ['red',['Red',['../group___estimator_group.html#gga9a9ac78ca6a5f95037c789d0cf2776c5aee38e4d5dd68c4e440825018d549cb47',1,'fsdk']]],
  ['releasedinotherthread',['ReleasedInOtherThread',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a014e56b039fd19b57e203c1fb371f5ce',1,'fsdk::Image']]],
  ['reliable',['Reliable',['../group___estimator_group.html#gga088edfc69279e44300259c1e80b75037a84fcf5d37086f2a93953734ce8f385b6',1,'fsdk']]],
  ['righteye',['RightEye',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a8b7774b63b7308eb85c167317b85381d',1,'fsdk']]],
  ['rt_5fleft',['RT_LEFT',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371ae475a39f736c701675130af611f0bb1a',1,'fsdk']]],
  ['rt_5fnone',['RT_NONE',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a8f6424f13253573bbd220a3d8193b457',1,'fsdk']]],
  ['rt_5fright',['RT_RIGHT',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a635b8ceb92f4f4a32dfec92a7d31cb9b',1,'fsdk']]],
  ['rt_5fupside_5fdown',['RT_UPSIDE_DOWN',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a5c135105879d5cc6bccb7b7f44753a1a',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/enumvalues_e.js <==
var searchData=
[
  ['r16',['R16',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1ae6596410cdfb3e164d3114d7275c01a4',1,'fsdk::Format']]],
  ['r8',['R8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1afd28eabff68ce04d89a4a445c8774f11',1,'fsdk::Format']]],
  ['r8g8b8',['R8G8B8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a64d817782ee8b40de7073acc65267e76',1,'fsdk::Format']]],
  ['r8g8b8x8',['R8G8B8X8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a1531807037bb455d89b70ff0d6ff05fe',1,'fsdk::Format']]],
  ['real',['Real',['../group___estimator_group.html#gga94d3646e61ffe5c0c99ea0318e359bd7a7f80fcc452c2f1ed2bb51b39d0864df1',1,'fsdk::experimental::DeepFakeEstimation::Real()'],['../structfsdk_1_1_n_i_r_liveness_estimation.html#ab465ad1dcb3273ced350445ad51aa02aa7f80fcc452c2f1ed2bb51b39d0864df1',1,'fsdk::NIRLivenessEstimation::Real()'],['../structfsdk_1_1_photorealistic_face_estimation.html#a02d580080a36d0718bb4b1bb78178efba7f80fcc452c2f1ed2bb51b39d0864df1',1,'fsdk::PhotorealisticFaceEstimation::Real()']]],
  ['red',['Red',['../group___estimator_group.html#gga9a9ac78ca6a5f95037c789d0cf2776c5aee38e4d5dd68c4e440825018d549cb47',1,'fsdk']]],
  ['releasedinotherthread',['ReleasedInOtherThread',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a014e56b039fd19b57e203c1fb371f5ce',1,'fsdk::Image']]],
  ['reliable',['Reliable',['../group___estimator_group.html#gga088edfc69279e44300259c1e80b75037a84fcf5d37086f2a93953734ce8f385b6',1,'fsdk']]],
  ['righteye',['RightEye',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a8b7774b63b7308eb85c167317b85381d',1,'fsdk']]],
  ['rt_5fleft',['RT_LEFT',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371ae475a39f736c701675130af611f0bb1a',1,'fsdk']]],
  ['rt_5fnone',['RT_NONE',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a8f6424f13253573bbd220a3d8193b457',1,'fsdk']]],
  ['rt_5fright',['RT_RIGHT',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a635b8ceb92f4f4a32dfec92a7d31cb9b',1,'fsdk']]],
  ['rt_5fupside_5fdown',['RT_UPSIDE_DOWN',['../namespacefsdk.html#a2820383b5d614599dc7783ef87687371a5c135105879d5cc6bccb7b7f44753a1a',1,'fsdk']]]
];
